CupertinoInputAccessory class

A widget that provides input accessory functionality on iOS.

This widget tracks the height of its child and communicates this information to the native iOS implementation to properly handle keyboard layout when using input accessory views. On iOS, it provides the necessary integration for custom input accessory views. On other platforms, it simply returns the child widget without any modifications.

Input accessory views are typically used to add custom toolbars or controls above the keyboard.

Example usage:

CupertinoInputAccessory(
  child: Container(
    height: 44,
    child: Row(
      children: [
        TextButton(onPressed: () {}, child: Text('Done')),
      ],
    ),
  ),
)
Inheritance

Constructors

CupertinoInputAccessory({Key? key, required Widget child})
Creates a CupertinoInputAccessory widget.
const

Properties

child Widget
The widget below this widget in the tree. This typically contains the input accessory UI elements.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited